searchNodes=[{"type":"module","title":"PipeHelpers","doc":"Helpers for piping data. The provided helpers can be grouped into two categories: generate tuples that fit the return type of the containing function deal with previous function tuple output without &quot;breaking the pipe&quot; 1. Return tuples builders You can use only the first category to improve readability in your code. For instance, lets take a typical Phoenix.LiveView code: def mount ( _params , _session , socket ) do socket = assign ( socket , my_bool_assign : true ) { :ok , socket } end With ok/1 , it can be rewritten as: def mount ( _params , _session , socket ) do socket |&gt; assign ( my_bool_assign : true ) |&gt; ok ( ) end In addition to the typical {:ok, value} return tuple, the library provides the most common return types helpers noreply/1 reply/2 . Generic helpers are also provided to build whatever tuple you need with pair/2 and rpair/2 . 2. Tuple deconstructors In some situations, return type incompatibilities prevent you from using an uninterrupted pipe sequence. In this case, the following helpers may help: 2a Generic unpair The generic unpair/1 allows you to ignore the first element of the pair and forward the second for further piping. 2b Only when &quot;ok&quot; execution The then_ok/2 provides a promise-like solution to handle 'maybe ok' results. If the result is an ok-tuple, it executes the function on the second argument and passes the result forward (i.e. for further piping). If the result is not an ok-tuple (typically an {:error, message} tuple), it is forwarded directly. For example, let's take the following (very powerful translator) function: def translate ( source ) do case source do &quot;ola&quot; -&gt; { :ok , &quot;hello&quot; } _ -&gt; { :error , &quot;can&#39;t translate, sorry&quot; } end end And the quoting function that you want to pipe into: def quote ( text ) do text end The translate/1 output doesn't fit the quote/1 input, so the following pipe is not possible: my_source |&gt; translate ( ) |&gt; quote ( ) With the then_ok/2 you can handle do: my_source |&gt; translate ( ) |&gt; then_ok ( &amp; quote / 1 ) This pipe will either return the properly quoted translation or the error tuple generated by the translate/1 . If you intend to successively pipe into more than a single functions after an {:ok, result} returning function, you need to only have {:ok, result} functions except the last one and always use the then_ok/2 construct until the end. Doing so you can safely do the error management at the end of the pipe using a |&gt; case do irrespective of the function that failed to provide an {:ok, result} output. The then_on/3 provides similar behaviour with a more generic/powerful pattern matching on the previous function output. The functions above have their tap counterpart if the idea is to apply a conditional side effect without modifying the piped value.","ref":"PipeHelpers.html"},{"type":"function","title":"PipeHelpers.noreply/1","doc":"Wrap into {:noreply, state} tuple (genserver and phoenix socket format). Example iex&gt; state = &quot;gen server state&quot; ...&gt; state |&gt; noreply ( ) { :noreply , &quot;gen server state&quot; }","ref":"PipeHelpers.html#noreply/1"},{"type":"function","title":"PipeHelpers.ok/1","doc":"Wrap into standard {:ok, result} tuple. Example iex&gt; socket = &quot;socket&quot; ...&gt; socket |&gt; ok ( ) { :ok , &quot;socket&quot; }","ref":"PipeHelpers.html#ok/1"},{"type":"function","title":"PipeHelpers.pair/2","doc":"Wrap into generic tuple pair. Example iex&gt; 1 |&gt; pair ( 2 ) { 2 , 1 }","ref":"PipeHelpers.html#pair/2"},{"type":"function","title":"PipeHelpers.reply/2","doc":"Wrap into {:reply, reply, state} tuple (genserver and phoenix socket format). Example iex&gt; state = &quot;gen server state&quot; ...&gt; r = &quot;reply&quot; ...&gt; state |&gt; reply ( r ) { :reply , &quot;reply&quot; , &quot;gen server state&quot; }","ref":"PipeHelpers.html#reply/2"},{"type":"function","title":"PipeHelpers.rpair/2","doc":"Wrap into tuple rpair. Example iex&gt; 1 |&gt; rpair ( 2 ) { 1 , 2 }","ref":"PipeHelpers.html#rpair/2"},{"type":"function","title":"PipeHelpers.tap_ok/2","doc":"Execute fun function only if result is an ok-tuple. Returns the input in any case. The fun argument is a function taking the right part of the ok-tuple as an optional argument. Example iex&gt; { :ok , &quot;somedata&quot; } |&gt; tap_ok ( fn -&gt; &quot;only executed when {:ok, ...}&quot; end ) { :ok , &quot;somedata&quot; } iex&gt; { :error , &quot;failed&quot; } |&gt; tap_ok ( fn -&gt; &quot;not executed when not {:ok, ...}&quot; end ) { :error , &quot;failed&quot; }","ref":"PipeHelpers.html#tap_ok/2"},{"type":"function","title":"PipeHelpers.tap_on/3","doc":"Execute fun function only if the first arument matches the second one ( value = result check). Returns the input in any case. Example iex&gt; true |&gt; tap_on ( true , fn -&gt; &quot;only executed when matching &#39;true&#39;&quot; end ) true iex&gt; false |&gt; tap_on ( true , fn -&gt; &quot;not executed when not matchin &#39;true&#39;&quot; end ) false","ref":"PipeHelpers.html#tap_on/3"},{"type":"function","title":"PipeHelpers.then_ok/2","doc":"If result is an ok tuple, execute fun with the right part of result tuple as single argument and return fun output. Otherwise, return result as-is. Example iex&gt; { :ok , &quot;somedata&quot; } |&gt; then_ok ( fn -&gt; &quot;only returned when result argument is {:ok, ...}&quot; end ) &quot;only returned when result argument is {:ok, ...}&quot; iex&gt; { :error , &quot;failed&quot; } |&gt; then_ok ( fn -&gt; &quot;only returned when result argument is {:ok, ...}&quot; end ) { :error , &quot;failed&quot; }","ref":"PipeHelpers.html#then_ok/2"},{"type":"function","title":"PipeHelpers.then_on/3","doc":"Then only if value match. See then_ok/2 and tap_ok/3","ref":"PipeHelpers.html#then_on/3"},{"type":"function","title":"PipeHelpers.unpair/1","doc":"Unwrap from a tuple pair. Example iex&gt; { :ok , 1 } |&gt; unpair ( ) 1","ref":"PipeHelpers.html#unpair/1"},{"type":"module","title":"PipeHelpers.Flow","doc":"","ref":"PipeHelpers.Flow.html"},{"type":"function","title":"PipeHelpers.Flow.map_ok/2","doc":"","ref":"PipeHelpers.Flow.html#map_ok/2"},{"type":"function","title":"PipeHelpers.Flow.start/2","doc":"","ref":"PipeHelpers.Flow.html#start/2"},{"type":"function","title":"PipeHelpers.Flow.start/3","doc":"","ref":"PipeHelpers.Flow.html#start/3"},{"type":"function","title":"PipeHelpers.Flow.tap_ok/2","doc":"","ref":"PipeHelpers.Flow.html#tap_ok/2"},{"type":"function","title":"PipeHelpers.Flow.then_ok/3","doc":"","ref":"PipeHelpers.Flow.html#then_ok/3"},{"type":"extras","title":"README","doc":"PipeHelpers Pipe helpers are a set of simple helpers for elixir to help structure code with pipes.","ref":"readme.html"},{"type":"extras","title":"README - Installation","doc":"The package can be installed by adding pipe_helpers to your list of dependencies in mix.exs : def deps do [ { :pipe_helpers , &quot;~&gt; 1.0.1&quot; } ] end","ref":"readme.html#installation"},{"type":"extras","title":"README - Documentation","doc":"The library is documented in the main module documentation . Small example: import PipeHelpers # Example in a live view @impl true def mount ( _params , _session , socket ) do socket |&gt; assign ( loading : true ) |&gt; ok ( ) end","ref":"readme.html#documentation"}]